import unittest

from .dsl import DslTestCase
from .coordination import CoordinationTestCase
from .expect import ExpectTestCase

def all_tests():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(DslTestCase))
    suite.addTest(unittest.makeSuite(CoordinationTestCase))
    suite.addTest(unittest.makeSuite(ExpectTestCase))
    return suite




import unittest
from pyshould import *
from pyshould.expect import expect, expect_all, expect_any, expect_none

class ExpectTestCase(unittest.TestCase):
    """ Simple tests for the expect based api """

    def test_expect(self):
        expect(1).to_equal(1)
        expect(1).to_not_equal(0)

    def test_expect_all(self):
        expect_all([1,2]).to_be_integer()
        expect_all(1, 2).to_be_integer()

    def test_expect_any(self):
        expect_any([1,2]).to_equal(2)
        expect_any(1,2).to_equal(2)

    def test_expect_none(self):
        expect_none([1,2]).to_equal(0)
        expect_none(1,2).to_equal(0)

    def test_expect_quantifiers(self):
        expect(all_of(1, 2)).to_be_integer()
        expect(any_of([1, 2])).to_eq(1)




"""
Define the names making up the domain specific language
"""

from pyshould.expectation import (
    Expectation, ExpectationNot,
    ExpectationAll, ExpectationAny,
    ExpectationNone, OPERATOR
)

__author__ = "Ivan -DrSlump- Montes"
__email__ = "drslump@pollinimini.net"
__license__ = "MIT"

# Create instances to be used with the overloaded | operator
should = Expectation(deferred=True, factory=True)
should_not = ExpectationNot(deferred=True, factory=True)
should_all = ExpectationAll(deferred=True, factory=True)
should_any = ExpectationAny(deferred=True, factory=True)
should_none = ExpectationNone(deferred=True, factory=True)
should_either = Expectation(deferred=True, factory=True, def_op=OPERATOR.OR)


def it(value):
    """ Wraps a value in an expectation """
    return Expectation(value)


def any_of(value, *args):
    """ At least one of the items in value should match """

    if len(args):
        value = (value,) + args

    return ExpectationAny(value)


def all_of(value, *args):
    """ All the items in value should match """

    if len(args):
        value = (value,) + args

    return ExpectationAll(value)


def none_of(value, *args):
    """ None of the items in value should match """

    if len(args):
        value = (value,) + args

    return ExpectationNone(value)



import pyshould

__author__ = "Ivan -DrSlump- Montes"
__email__ = "drslump@pollinimini.net"
__license__ = "MIT"


def expect(value, *args):
    if len(args):
        return expect_all(value, *args)
    else:
        return expect_it(value)


def expect_it(value):
    return pyshould.it(value)


def expect_all(*args):
    return pyshould.all_of(*args)


def expect_any(*args):
    return pyshould.any_of(*args)


def expect_none(*args):
    return pyshould.none_of(*args)
